<?php
/**
 * $Horde: vilma/domains/edit.php,v 1.14 2005/01/03 14:35:41 jan Exp $
 *
 * Copyright 2003-2005 Marko Djukic <marko@oblo.com>
 *
 * See the enclosed file LICENSE for license information (BSD). If you did not
 * receive this file, see http://cvs.horde.org/co.php/vilma/LICENSE.
 */

@define('VILMA_BASE', dirname(__FILE__) . '/..');
require_once VILMA_BASE . '/lib/base.php';
require_once 'Horde/Form.php';
require_once 'Horde/Variables.php';

/* Only admin should be using this. */
if (!Auth::isAdmin() && !Vilma::isDomainAdmin()) {
    Horde::authenticationFailureRedirect();
}

$vars = &Variables::getDefaultVariables();
$user = $vars->get('user');
//$domain = Vilma::getDomain();
$domain_id = $vars->get('domain_id');

$form = &Horde_Form::singleton('', $vars);

/* Check if a form is being edited. */
$editing = false;
if ($domain_id && !$form->isSubmitted()) {
    $vars = &new Variables($vilma->getDomain($domain_id));
    $editing = true;
}
$title = ($editing) ? _("Edit Domain") : _("New Domain");
$form->setTitle($title);

/* Set up the form. */
$form->setButtons(true, true);
$form->addHidden('', 'domain_id', 'text', false);
$form->addVariable(_("Domain"), 'domain_name', 'text', true);
require_once 'Horde/Array.php';
$form->addVariable(_("Transport"), 'domain_transport', 'enum', false, false, null, array(Horde_Array::valuesToKeys($conf['mta']['transports'])));
$form->addVariable(_("Domain admin"), 'domain_admin', 'text', true);
$form->addVariable(_("Max users"), 'domain_max_users', 'int', false);
$form->addVariable(_("Quota"), 'domain_quota', 'int', false, false, _("Value in MB"));

if ($form->validate($vars)) {
    $form->getInfo($vars, $info);
    $info['domain_name'] = String::lower($info['domain_name']);
    $info['domain_admin'] = String::lower($info['domain_admin']);
    $domain_id = $vilma->saveDomain($info);
    if (is_a($domain_id, 'PEAR_Error')) {
        Horde::logMessage($domain_id, __FILE__, __LINE__, PEAR_LOG_ERR);
        $notification->push(sprintf(_("Error saving domain. %s."), $domain_id->getMessage()), 'horde.error');
    } else {
        $notification->push(_("Domain saved."), 'horde.success');
        $url = Horde::applicationUrl('domains/index.php', true);
        header('Location: ' . $url);
        exit;
    }
}

/* Render the form. */
require_once 'Horde/Form/Renderer.php';
$renderer = &new Horde_Form_Renderer();
$main = Util::bufferOutput(array($form, 'renderActive'), $renderer, $vars, 'edit.php', 'post');

$template->set('main', $main);
$template->set('menu', Vilma::getMenu('string'));
$template->set('notify', Util::bufferOutput(array($notification, 'notify'), array('listeners' => 'status')));

require VILMA_TEMPLATES . '/common-header.inc';
echo $template->fetch(VILMA_TEMPLATES . '/main/main.html');
require $registry->get('templates', 'horde') . '/common-footer.inc';
